﻿<?xml version="1.0" encoding="UTF-8"?>     
<#-- Import common macros and functions -->
<#import "macros_common_general.ftl" as com>
<#include "spc_utils.ftl">
<#import "spc_utils.ftl" as spcUtils>
<#import "common_module_classification_and_labelling.ftl" as keyClassifcationAndLabellingInformation>

<@com.initializeMainVariables/>
<@com.initiateRelevanceSPC relevance/>

<#if spcSingleContext?has_content>
  <#assign data = spcSingleContext?eval_json />  

    <#if data.authorisationNumber?has_content>
      <#global externalAuthorisationNumber = data.authorisationNumber/>
    </#if>

    <#if data.authorisationHolderName?has_content>
      <#global externalAuthorisationName = data.authorisationHolderName/>
    </#if>

    <#if data.authorisationHolderAddress?has_content>
      <#global externalAuthorisationAddressStreet = data.authorisationHolderAddress.street/>
      <#global externalAuthorisationAddressPostalCode = data.authorisationHolderAddress.postalCode/>
      <#global externalAuthorisationAddressCity = data.authorisationHolderAddress.city/>
      <#global externalAuthorisationAddressCountry = data.authorisationHolderAddress.country.code/>    
    </#if>

    <#if data.validityStartDateStandardPhrase?has_content>
      <#global externalAuthorisationStartDate = data.validityStartDateStandardPhrase/> 
    </#if>

    <#if data.validityEndDateStandardPhrase?has_content>
      <#global externalAuthorisationEndDate = data.validityEndDateStandardPhrase/> 
    </#if>
    
</#if>

<#assign sysDateTime = .now>
<book version="5.0" xmlns="http://docbook.org/ns/docbook" xmlns:xi="http://www.w3.org/2001/XInclude">

<#-- get dossier header variable to reuse -->
<#assign dossier = _dossierHeader />

 <!-- put in assign the language code as selected in dossier header, and base the hardcoded language output on this.
The *languageLocale is made global in the spc_utils so that it can be used -->
  <#if dossier.submissionType?matches(".*SPC.*") && dossier.SpecificSubmissions.Language?has_content>
  <#assign firstLanguage = dossier.SpecificSubmissions.Language>
  <#assign localizedPhrase = (iuclid.localizedPhraseDefinitionFor(firstLanguage.code, locale)) />
    <#if localizedPhrase.description?has_content>
      <#global languageLocale>${localizedPhrase.description}</#global>
    <#else>
      <#assign languageLocale><#assign locale = "en"></#assign>
    </#if>
    <#else>
      <#assign languageLocale><#assign locale = "en"></#assign>
  </#if>

  <#import "translations_spc.ftl" as translations>
  <#include "translations_spc.ftl">
  <@translations.translateSPC/>

<#assign hist = ""/>
<#assign historyList = (getFirstHistoryOnly(_subject))!"" />
<#assign hist><#if historyList?has_content>${historyList.date}<#else>.</#if></#assign>
<#assign last_upd>${last_updated}</#assign>

  <#assign left_header_text = ''/> 
	<#assign central_header_text = "" />
	<#assign right_header_text = ''/>
	
	<#assign left_footer_text = sysDateTime?string["dd/MM/yyyy"] + " - IUCLID 6 " + iuclid6Version!/> 
	<#assign central_footer_text = '' />
	<#assign right_footer_text = ''/>

<info>
<@com.localizeXsl languageLocale />
<@com.tocDepth 2 />
  <title>
    <para><para text-align="center" role="medium">${languageLocale?upper_case}</para></para>         
    <para><para text-align="center" role="medium"><emphasis>${cover_page_annex?upper_case}</emphasis></para></para>
    <@com.emptyLine/>   
    <para><para text-align="center" role="medium">${info_title_single?upper_case}</para></para> 
  </title>
			
		<cover>	

      <para role="align-center">
      <para role="medium">
        <@spcUtils.frontPageCompositionNames mainMixtureCompositionList "product" />
            
        <@com.emptyLine />
        <emphasis role="bold">${cover_page_product_types}</emphasis>
        <para><@spcUtils.productTypes usesList "usesListId" /></para>

        <#-- macro to populate dossier header related information -->
        <#if _dossierHeader?has_content>
          <@spcUtils.macroForPopulatingDossierHeader _dossierHeader />
        </#if>

        <#if _dossierHeader?has_content>
        <@com.emptyLine />
            <para>
            <emphasis role="bold">${cover_page_auth_number}:</emphasis> <@com.text authNumber />
            </para>
        </#if>
            
        <#if _dossierHeader?has_content>
        <@com.emptyLine />
          <para>
          <emphasis role="bold">${cover_page_asset_number}:</emphasis>
          <#if _dossierHeader.SpecificSubmissions.AuthorisationDetails.ReferenceNumber?has_content>
            <@com.text _dossierHeader.SpecificSubmissions.AuthorisationDetails.ReferenceNumber />
          <#elseif !(_dossierHeader.SpecificSubmissions.AuthorisationDetails.ReferenceNumber?has_content)>
            <@com.text externalAuthorisationNumber />
          </#if>          
          </para>
        </#if>
            
      </para> 
      </para> 

    </cover>      
		<@com.metadataBlock left_header_text central_header_text right_header_text left_footer_text central_footer_text right_footer_text />
</info>

<#------------------------------------>
<#-- START OF CHAPTERS AND SECTIONS -->
<#------------------------------------>

<chapter label="1">
<!-- 1. ADMINISTRATIVE INFORMATION -->
<title role="HEAD-1">${chapter_1_family_chapter_1_single}</title>
  
  <!-- 1.1 Trade name(s) of the product -->     
  <section><title role="HEAD-2"><@spcUtils.addWhiteSpaces 2/>${section_1_1_single}</title>
  <#if mainMixtureCompositionList?has_content>
  <#list mainMixtureCompositionList as composition>
    <#if composition.GeneralInformation.TradeNames?has_content>
      <#assign repeatableBlock = composition.GeneralInformation.TradeNames/>
      <#if repeatableBlock?has_content>
      <@spcUtils.verticalHeaderTable repeatableBlock isMoreThanOneDoc(mainMixtureCompositionList) _subject repeatableBlock "${part_2_table7_cell1_family_table1_1_cell1_single}" "headerPlaceholder" "headerPlaceholder" "headerPlaceholder" "headerPlaceholder" "headerPlaceholder" "headerPlaceholder" "headerPlaceholder" "twoColTable" "${tableID.table_id_1}"/>
      </#if>
    </#if>
  </#list>
  </#if>
  </section>

  <!-- 1.2 Authorisation holder -->
  <section><title role="HEAD-1"><@spcUtils.addWhiteSpaces 2/>${section_1_3_family_section_1_2_single}</title>
  <#if dossier?has_content>
  <#assign submittingLegalEntity = iuclid.getDocumentForKey(dossier.SpecificSubmissions.AuthorisationDetails.AuthorisationHolder) />
      <@spcUtils.macroForPopulatingLegalEntity submittingLegalEntity "${tableID.table_id_3}" />        
      <@spcUtils.verticalHeaderTable "repeatableBlock" "isMoreThanOneDoc" _subject "repeatableBlock" "${part_1_table1_3_cell1_family_table1_2_cell1_single}" "${part_1_table1_3_cell2_family_table1_2_cell2_single}" "${part_1_table1_3_cell3_family_table1_2_cell3_single}" "${part_2_table7_cell3_family}" "${part_1_table1_3_cell5_family_table1_2_cell5_single}" "${part_1_table1_3_cell6_family_table1_2_cell6_single}" "${part_1_table1_3_cell7_family_table1_2_cell7_single}" "headerPlaceholder" "threeColTable" "${tableID.table_id_3}"/> 
  </#if>
  </section>
  
  <#-- suppliers info and active substance key for 1.3 and 1.4 -->
  <@getMeAllSuppliersAndSites/>

  <!-- 1.3 Manufacturer(s) of the product -->
  <section><title role="HEAD-1"><@spcUtils.addWhiteSpaces 2/>${section_1_4_family_section_1_3_single}</title>
  <@spcUtils.manufacturerOfTheProduct/>
  </section>

  <!-- 1.4 Manufacturer(s) of the active substance(s) -->
  <section><title role="HEAD-1"><@spcUtils.addWhiteSpaces 2/>${section_1_5_family_section_1_4_single}</title>
  <@spcUtils.manufacturerOfTheActiveSubstanceSection "notMeta" "compositionProduct"/>
  </section>
</chapter>

<chapter label="2">
<!-- 2. PRODUCT COMPOSITION AND FORMULATION -->
<title role="HEAD-1">${chapter_2_single}</title>

  <!-- 2.1 Qualitative and quantitative information on the composition of the product -->
  <section><title role="HEAD-1"><@spcUtils.addWhiteSpaces 2/>${section_2_1_single}</title>
   <#assign repeatableBlock = spcUtils.getComponents(mainMixtureCompositionList, "${tableID.table_id_2}")/>
   <#if repeatableBlock?has_content>
   <@spcUtils.horizontalHeaderTable repeatableBlock isMoreThanOneDoc(mainMixtureCompositionList) _subject repeatableBlock "${part_1_part_2_table2_1_table7_cell1_family_table2_1_cell1_single}" "${part_1_part_2_table2_1_table7_cell2_family_table2_1_cell2_single}" "${part_1_part_2_table2_1_table7_cell3_family_table2_1_cell3_single}" "${part_1_part_2_table2_1_table7_cell4_family_table2_1_cell4_single}" "${part_1_part_2_table2_1_table7_cell5_family_table2_1_cell5_single}" "${part_1_part_2_table2_1_table7_cell6_family_table2_1_cell6_single}" "sixColTable" "${tableID.table_id_2}"/>
   </#if>
  </section>
 
  <!-- 2.1 Type of formulation -->
  <section><title role="HEAD-1"><@spcUtils.addWhiteSpaces 2/>${section_2_2_family_section_2_2_single}</title>
  <#if mainMixtureCompositionList?has_content>
    <#list mainMixtureCompositionList as composition>
    <#if composition?has_content>
      <para><@spcUtils.picklistMultipleWoutSemiColon composition.GeneralInformation.FormulationType/></para>
    </#if>
    </#list>
  </#if>  
  </section>
</chapter>

<chapter label="3">
  <!-- 3. HAZARD AND PRECAUTIONARY STATEMENTS -->
  <title role="HEAD-1">${chapter_3_single}</title>
  <@spcUtils.macroForPopulatingGhsLabelling ghsList "${tableID.table_id_4}" /> 
  <#if ghsList?has_content>
    <@spcUtils.verticalHeaderTable ghsList isMoreThanOneDoc(ghsList) _subject ghsList "${part_2_table_3_cell1_family_table3_cell1_single}" "${part_2_table_3_cell2_family_table3_cell2_single}" "headerPlaceholder" "headerPlaceholder" "headerPlaceholder" "headerPlaceholder" "headerPlaceholder" "headerPlaceholder" "twoColTable" "${tableID.table_id_4}"/>     
  </#if>
</chapter>
  
<chapter label="4">
  <!-- 4. AUTHORISED USE(S) -->
  <title role="HEAD-1">${chapter_4_single}</title>

  <!-- 4.1 Use description -->
  
  <#if usesList?has_content>
    <#list usesList as use>
    <section><title role="HEAD-4"><@spcUtils.addWhiteSpaces 2/>${part_2_section_4_1_family_section_4_1_table_single_use_description}</title>
      <#assign indexcounter>${use?index + 1}</#assign><@spcUtils.macroForUseData use "${languageLocale}" />
        <@spcUtils.useDescription isMoreThanOneDoc(usesList) use indexcounter "${part_2_table4_1_cell1_family_table4_1_cell1_single}" "${part_2_table4_1_cell2_family_table4_1_cell2_single}" "${part_2_table4_1_cell3_family_table4_1_cell3_single}" "${part_2_table4_1_cell4_family_table4_1_cell4_single}" "${part_2_table4_1_cell5_family_table4_1_cell5_single}" "${part_2_table4_1_cell6_family_table4_1_cell6_single}" "${part_2_table4_1_cell7_family_table4_1_cell7_single}" "${part_2_table4_1_cell8_family_table4_1_cell8_single}"/>     
        <@spcUtils.directionsForUseReferencedByAuthorisedUses use "${tableID.table_id_5}"/>
    </section>
    </#list>
  </#if>    
  
</chapter>

<chapter label="5">
<!-- 5. GENERAL DIRECTIONS FOR USE -->
<title role="HEAD-1">${part_2_chapter_5_single}<footnote>
<para>${footnote_chapter_5_single}</para>
</footnote></title>

  <#-- macro to only get protection measures *protectionMeasuresList* not linked to authorised uses -->
  <#assign proM = getProtectionVariable(protectionMeasuresList, usesList)>

  <!-- 5.1 Instructions for use -->
  <section><title role="HEAD-4"><@spcUtils.addWhiteSpaces 2/><@spcUtils.staticText "part_2_section_5.1_family_part_2_section_5.1_single"/></title>
  <#if proM?has_content>
  <#list proM as proMeasures>
    <#if proMeasures.InstructionsForUse.InstructionsForUse?has_content>
     <msgtext><@com.richText proMeasures.InstructionsForUse.InstructionsForUse /></msgtext>
    </#if>  
  </#list>
  </#if>
  </section>
  
  <!-- 5.2 Risk mitigation measures -->
  <section><title role="HEAD-4"><@spcUtils.addWhiteSpaces 2/><@spcUtils.staticText "part_2_section_5.2_family_part_2_section_5.2_single"/></title>
  <#if proM?has_content>
  <#list proM as proMeasures>
    <#if proMeasures.MeasuresToProtect.ControlMeasuresOfRepellents?has_content>
      <msgtext><@com.richText proMeasures.MeasuresToProtect.ControlMeasuresOfRepellents /></msgtext>
    </#if>
  </#list>  
  </#if>
  </section>

  <!-- 5.3 Particulars of likely direct or indirect effects, first aid instructions and emergency measures to protect the environment -->
  <section><title role="HEAD-4"><@spcUtils.addWhiteSpaces 2/><@spcUtils.staticText "part_2_section_5.3_family_part_2_section_5.3_single"/></title>
  <#if proM?has_content>
  <#list proM as proMeasures>
    <#if proMeasures.MeasuresToProtect.ParticularsOfLikelyDirect?has_content>
      <msgtext><@com.richText proMeasures.MeasuresToProtect.ParticularsOfLikelyDirect /></msgtext>
    </#if>
  </#list> 
  </#if>
  </section>

  <!-- 5.4 Instructions for safe disposal of the product and its packaging -->
  <section><title role="HEAD-4"><@spcUtils.addWhiteSpaces 2/><@spcUtils.staticText "part_2_section_5.4_family_part_2_section_5.4_single"/></title>
  <#if proM?has_content>
  <#list proM as proMeasures>
    <#if proMeasures.ProceduresForWasteManagement.InstructionsForSafeDisposal?has_content>
      <msgtext><@com.richText proMeasures.ProceduresForWasteManagement.InstructionsForSafeDisposal /></msgtext>
    </#if>
  </#list>
  </#if>
  </section>

  <!-- 5.5 Conditions of storage and shelf-life of the product under normal conditions of storage -->
  <section><title role="HEAD-4"><@spcUtils.addWhiteSpaces 2/><@spcUtils.staticText "part_2_section_5.5_family_part_2_section_5.5_single"/></title>
  <#if proM?has_content>
  <#list proM as proMeasures>
    <#if proMeasures.MeasuresToProtect.RecommendedMethodsAndPrecautionsConcerningStorage?has_content>
      <msgtext><@com.richText proMeasures.MeasuresToProtect.RecommendedMethodsAndPrecautionsConcerningStorage /></msgtext>
    </#if>
  </#list>
  </#if>
  </section>
</chapter>

<chapter label="6">
<!-- 6 OTHER INFORMATION -->
<title role="HEAD-1">${part_2_chapter_6_family_part_2_chapter_6_single}</title>
  <#if otherInformationList?has_content>
    <#list otherInformationList as otherInformation>
    <#if otherInformation?has_content>
        <msgtext><@com.richText otherInformation.OtherInformation.OtherInformation /></msgtext>
    </#if>
    </#list>
  </#if>  
</chapter>

<#function getProtectionVariable protectionMeasuresList usesList>

  <#assign protectionMeasuresNotLinkedToUses = [] />
  <#assign protectionMeasuresUUID = [] />

  <#if usesList?has_content>
    <#list usesList as uses> 
      <#if uses?has_content>     
        <#assign protectionMeasuresLinked = iuclid.getDocumentForKey(uses.IntendedUsesAndExposure.InstructionsForUseAndMeasuresToProtect)/>       
        <#if protectionMeasuresLinked?has_content>
          <#assign protectionMeasuresUUID = protectionMeasuresUUID + [protectionMeasuresLinked.documentKey.uuid] />
        </#if>
      </#if>      
    </#list>
  </#if>

  <#if protectionMeasuresList?has_content>
    <#list protectionMeasuresList as protectionMeasures>
      <#if protectionMeasures?has_content>
        <#if !protectionMeasuresUUID?seq_contains(protectionMeasures.documentKey.uuid)>            
          <#assign protectionMeasuresNotLinkedToUses = protectionMeasuresNotLinkedToUses + [protectionMeasures] />
        </#if>
      </#if>
    </#list>
  </#if>
  <#return protectionMeasuresNotLinkedToUses>
</#function>

<#macro getMeAllSuppliersAndSites>

    <#assign suppliers = [] />
    <#assign activeSubstanceSupplierList = [] />
    <#assign activeSubstanceSitesList = [] />
    <#assign legalEntity = [] />
    <#assign activeSubstancelegalEntity = [] />
    <#assign activeSubstanceSupplier = [] />
    <#assign activeSubstanceComponent = [] />
    
    <#if supplierList?has_content>
      <#list supplierList as supplier>
        <#if supplier?has_content>
          <#assign suppliers = suppliers + [supplier] />      
        </#if>
      </#list>
    </#if>

    <#assign activeSubtanceComponentList = spcUtils.getActiveSubstanceComponents(mainMixtureCompositionList)/>
    <#if activeSubtanceComponentList?has_content>
    <#list activeSubtanceComponentList as activeSubstanceComponents>
      <#if activeSubstanceComponents?has_content>

        <#assign activeSubstanceKey = iuclid.getDocumentForKey(activeSubstanceComponents.Reference)/>
        <#assign activeSubstanceComponent = activeSubstanceComponent + [activeSubstanceComponents] />

        <#assign activeSubstanceSupplierList = iuclid.getSectionDocumentsForParentKey(activeSubstanceKey.documentKey, "FLEXIBLE_RECORD", "Suppliers") />
        <#assign activeSubstanceSitesList = iuclid.getSectionDocumentsForParentKey(activeSubstanceKey.documentKey, "FLEXIBLE_RECORD", "Sites") />
       
       <#if activeSubstanceSupplierList?has_content>
        <#list activeSubstanceSupplierList as activeSubstanceSuppliers>
          <#if activeSubstanceSuppliers?has_content>         
            <#assign activeSubstanceSupplier = activeSubstanceSupplier + [activeSubstanceSuppliers] />
          </#if>
        </#list>
        </#if> 

      </#if>
    </#list>
    </#if>
</#macro>


<#---------------->
<#-- END MACROS -->
<#---------------->

<#--------------------->
<#-- START FUNCTIONS -->
<#--------------------->

<#function isMoreThanOneDoc sectionDoc>
<#if sectionDoc?size gt 0>
  <#return true>
  <#else>
    <#return false/>
</#if>
  <#return false/>
</#function>

<#function getFirstHistoryOnly _subject>
<#attempt>
<#local historyList = iuclid.getHistoryForDocumentKey(_subject.documentKey) />
		
	<#if historyList?? && historyList?has_content>		
		<#list historyList as history>	
			<#if !(history)?has_content>
				<#return [] />	
				<#else/>
					<#return historyList[0] />					
			</#if>
		</#list>
	</#if>	
			
	<#recover>
		
	<#return [] />	
</#attempt>
	<#return [] />			
</#function>			

<#------------------->
<#-- END FUNCTIONS -->
<#------------------->

</book>
